<?php
/**
 * neblue functions and definitions
 *
 * @package neblue
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'neblue_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function neblue_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on neblue, use a find and replace
	 * to change 'neblue' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'neblue', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	//add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'menu-1' => __( 'Primary Menu', 'neblue' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );
	
	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'neblue_custom_background_args', array(
		'default-image' => get_template_directory_uri().'/images/bg.png',
		'default-repeat' => 'repeat',
	) ) );
	
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size(1000, 300, true );
	
	add_editor_style();
}
endif; // neblue_setup
add_action( 'after_setup_theme', 'neblue_setup' );

/**
 * Enqueue scripts and styles.
 */
function neblue_scripts() {
	wp_enqueue_style( 'neblue-style', get_stylesheet_uri() );
	
	wp_enqueue_style( 'neblue-font-awesome',get_template_directory_uri().'/font-awesome/css/font-awesome.min.css',array() );
	
	wp_enqueue_style( 'neblue-google-fonts', 'http://fonts.googleapis.com/css?family=Open+Sans:400,400italic,700,700italic');

	wp_enqueue_script( 'neblue-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20120206', true );

	wp_enqueue_script( 'neblue-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );

	wp_enqueue_script( 'neblue-fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array('jquery'), '' );
	wp_enqueue_script( 'neblue-fitvids-doc-ready', get_template_directory_uri() . '/js/fitvids-doc-ready.js', array( 'jquery' ), '' );
	
	wp_enqueue_script( 'neblue-customjs', get_template_directory_uri() . '/js/custom.js',array('jquery'), '' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'neblue_scripts' );


/**
 * Fav icon for the site
 */
function neblue_favicon() {
	if ( of_get_option( 'neblue_activate_favicon', '0' ) == '1' ) {
		$neblue_favicon = of_get_option( 'neblue_favicon', '' );
		$neblue_favicon_output = '';
		if ( !empty( $neblue_favicon ) ) {
			$neblue_favicon_output .= '<link rel="shortcut icon" href="'.esc_url( $neblue_favicon ).'" type="image/x-icon" />';
		}
		echo $neblue_favicon_output;
	}
}
add_action( 'admin_head', 'neblue_favicon' );
add_action( 'wp_head', 'neblue_favicon' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once dirname( __FILE__ ) . '/inc/options-framework.php';

// Loads options.php from child or parent theme
$optionsfile = locate_template( 'options.php' );
load_template( $optionsfile );

require_once( get_template_directory() . '/inc/header-functions.php' );
require_once( get_template_directory() . '/inc/functions.php' );
require_once( get_template_directory() . '/inc/widgets/widgets.php' );
?>