<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package neblue
 */

if ( ! function_exists( 'neblue_entry_footer' ) ) :
/**
 * Prints HTML with meta information for the categories, tags and comments.
 */
function neblue_entry_footer() {
	$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
	if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
	}
	$time_string = sprintf( $time_string,
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_attr( get_the_modified_date( 'c' ) ),
		esc_html( get_the_modified_date() )
	);
	$posted_on = '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>';
	echo '<span class="posted-on"><i class="fa fa-calendar"></i> ' . $posted_on . '</span>';

	if ( 'post' == get_post_type() ) {
		$categories_list = get_the_category_list( __( ', ', 'neblue' ) );
		if ( $categories_list && neblue_categorized_blog() ) {
			printf( '<span class="cat-links"><i class="fa fa-list"></i> ' . '%1$s' . '</span>', $categories_list );
		}
	}
	edit_post_link( __( 'Edit', 'neblue' ), '<span class="edit-link"><i class="fa fa-edit"></i> ', '</span>' );
	
	if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
		echo '<span class="comments-link"><i class="fa fa-comments"></i> ';
		comments_popup_link( __( 'Leave a comment', 'neblue' ), __( '1 Comment', 'neblue' ), __( '% Comments', 'neblue' ) );
		echo '</span>';
	}
	
	if(is_single()){
		$tags_list = get_the_tag_list( '', __( ', ', 'neblue' ) );
		if ( $tags_list ) {
			printf( '<div class="post-tags"><span class="tags-links"><i class="fa fa-tags"></i> ' . '%1$s' . '</span></div>', $tags_list );
		}
	}
}
endif;

if ( ! function_exists( 'neblue_archive_title' ) ) :
function neblue_archive_title( $before = '', $after = '' ) {
	if ( is_category() ) {
		$title = sprintf( __( 'Category: %s', 'neblue' ), single_cat_title( '', false ) );
	} elseif ( is_tag() ) {
		$title = sprintf( __( 'Tag: %s', 'neblue' ), single_tag_title( '', false ) );
	} elseif ( is_author() ) {
		$title = sprintf( __( 'Author: %s', 'neblue' ), '<span class="vcard">' . get_the_author() . '</span>' );
	} elseif ( is_year() ) {
		$title = sprintf( __( 'Year: %s', 'neblue' ), get_the_date( _x( 'Y', 'yearly archives date format', 'neblue' ) ) );
	} elseif ( is_month() ) {
		$title = sprintf( __( 'Month: %s', 'neblue' ), get_the_date( _x( 'F Y', 'monthly archives date format', 'neblue' ) ) );
	} elseif ( is_day() ) {
		$title = sprintf( __( 'Day: %s', 'neblue' ), get_the_date( _x( 'F j, Y', 'daily archives date format', 'neblue' ) ) );
	} elseif ( is_tax( 'post_format' ) ) {
		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
			$title = _x( 'Asides', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
			$title = _x( 'Galleries', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-image' ) ) {
			$title = _x( 'Images', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-video' ) ) {
			$title = _x( 'Videos', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-quote' ) ) {
			$title = _x( 'Quotes', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-link' ) ) {
			$title = _x( 'Links', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-status' ) ) {
			$title = _x( 'Statuses', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-audio' ) ) {
			$title = _x( 'Audio', 'post format archive title', 'neblue' );
		} elseif ( is_tax( 'post_format', 'post-format-chat' ) ) {
			$title = _x( 'Chats', 'post format archive title', 'neblue' );
		}
	} elseif ( is_post_type_archive() ) {
		$title = sprintf( __( 'Archives: %s', 'neblue' ), post_type_archive_title( '', false ) );
	} elseif ( is_tax() ) {
		$tax = get_taxonomy( get_queried_object()->taxonomy );
		/* translators: 1: Taxonomy singular name, 2: Current taxonomy term */
		$title = sprintf( __( '%1$s: %2$s', 'neblue' ), $tax->labels->singular_name, single_term_title( '', false ) );
	} else {
		$title = __( 'Archives', 'neblue' );
	}

	/**
	 * Filter the archive title.
	 *
	 * @param string $title Archive title to be displayed.
	 */
	$title = apply_filters( 'get_the_archive_title', $title );

	if ( ! empty( $title ) ) {
		echo $before . $title . $after;
	}
}
endif;

if ( ! function_exists( 'neblue_archive_description' ) ) :
function neblue_archive_description( $before = '', $after = '' ) {
	$description = apply_filters( 'get_the_archive_description', term_description() );

	if ( ! empty( $description ) ) {
		/**
		 * Filter the archive description.
		 *
		 * @see term_description()
		 *
		 * @param string $description Archive description to be displayed.
		 */
		echo $before . $description . $after;
	}
}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function neblue_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'neblue_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,

			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'neblue_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so neblue_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so neblue_categorized_blog should return false.
		return false;
	}
}

/**
 * Flush out the transients used in neblue_categorized_blog.
 */
function neblue_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	// Like, beat it. Dig?
	delete_transient( 'neblue_categories' );
}
add_action( 'edit_category', 'neblue_category_transient_flusher' );
add_action( 'save_post',     'neblue_category_transient_flusher' );


function neblue_theme_comment($comment,$args,$depth){
	$GLOBALS['comment'] = $comment;
?>
	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
		<div id="div-comment-<?php comment_ID(); ?>" class="comment-body">
            <div class="comment-author"><?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size'] ); ?></div>
        
			<div class="comment-meta">
            	<?php printf( __( '%s', 'neblue' ), sprintf( '<span class="fn">%s</span>', get_comment_author_link() ) ); ?>
				<span><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
						<time datetime="<?php comment_time( 'c' ); ?>"><?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'neblue' ), get_comment_date(), get_comment_time() ); ?></time>
				</a></span>
                <?php edit_comment_link( __( 'Edit', 'neblue' ), '<span><i class="fa fa-edit"></i> ', '</span>' ); ?>

				<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'neblue' ); ?></p>
				<?php endif; ?>
			</div>

			<div class="comment-content"><div class="mscon"><?php comment_text();?></div></div>

			<div class="reply"><i class="fa fa-reply"></i> <?php comment_reply_link( array_merge( $args, array( 'add_below' => 'div-comment', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></div>
            
            <div class="clear"></div>
		</div>
<?php
}

function neblue_posts_navigation(){
	if( function_exists('the_posts_pagination') ){
		the_posts_pagination( array(
			'prev_text'          => '<i class="fa fa-arrow-left"></i>',
			'next_text'          => '<i class="fa fa-arrow-right"></i>',
			'before_page_number' => '<span class="meta-nav screen-reader-text">' . __( 'Page', 'neblue' ) . ' </span>',
		) );
	}else{
?>
<div id="page-nav-below">
<?php if ( get_next_posts_link() ) : ?>
<div class="nav-previous"><i class="fa fa-arrow-left"></i> <?php next_posts_link( __( 'Older posts', 'neblue' ) ); ?></div>
<?php endif; ?>

<?php if ( get_previous_posts_link() ) : ?>
<div class="nav-next"><?php previous_posts_link( __( 'Newer posts', 'neblue' ) ); ?> <i class="fa fa-arrow-right"></i></div>
<?php endif; ?>
</div>
<?php
	}
}

function neblue_post_navigation(){
	global $post;
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next = get_adjacent_post( false, '', false );
	if ( ! $next && ! $previous ) return;

	echo '<div role="navigation" id="nav-below" class="navigation-post">';
	previous_post_link( '<div class="nav-previous">%link</div>', '<i class="fa fa-arrow-left"></i> %title');
	next_post_link( '<div class="nav-next">%link</div>', '%title <i class="fa fa-arrow-right"></i>'); 
	echo '<div class="clear"></div>';
	echo '</div>';
}
?>